==> rcm-1.3.5.tar.gz: rcm-1.3.5/NEWS.md <==
rcm (1.3.5) unstable; urgency=low

  * BUGFIX: *:*~ exclude paterns work again (Alexander Goldstein)
  * BUGFIX: messages for -C being a copy so can't update (Mat M).
  * BUGFIX: expect at least one existing dotfiles directory (Mat M).
  * BUGFIX: fix program name in rcdn -V (Ivan Tkachenko)
  * Feature: mkrc hooks via -k/-K (Patrick Brisbin)
  * Feature: All symlinks in input are rejected (Mat M).
  * Package and maintenance improvements (Alexander Goldstein, Eric Collins,
      Mat M, Darcy Parker).
  
 -- Mike Burns <mburns@thoughtbot.com>  Fri, 13 Jul 2018 14:12:00 -0500

rcm (1.3.4) unstable; urgency=low

  * BUGFIX: Globs no longer expand permanently (Edd Salkield).
  * BUGFIX: Show $ for symlinked dirs in `lsrc -F` (Mathias Michel).
  * BUGFIX: all symlinks in mkrc input are rejected (Mat M).
  * Packaging improvements (Stephen Groat, Martin Frost, Link Dupont)
  
 -- Mike Burns <mburns@thoughtbot.com>  Fri, 13 Jul 2018 14:12:00 -0500

rcm (1.3.3) unstable; urgency=low

  * Feature: Expand ~ in DOTFILES_DIR hooks (Eric Collins).

 -- Mike Burns <mburns@thoughtbot.com>  Fri, 13 Jul 2018 14:12:00 -0500

rcm (1.3.2) unstable; urgency=low

  * BUGFIX: Use =, not ==, in test(1) (Florian Tham).
  * BUGFIX: Directories with spaces in rcup(1) (Florian Tham).
  * BUGFIX: Fallback the LOGNAME from whoami (AJ Villalobos, Mike Burns).
  * BUGFIX: Fix cd for paths beginning with hyphen (-) (Christian Höltje).
  * Feature: Expand ~ in DOTFILES_DIR (Rebecca Meritz).
  * Documentation improvements (Alan Yee, Eric Collins, Florian Tham, kajisha,
	    Matthew Horan, maxice8, Mike Burns, Rebecca Meritz, Scott Stevenson,
	    Tyson Gach, Yota Toyama).

 -- Mike Burns <mburns@thoughtbot.com>  Fri, 06 Jul 2018 11:00:00 -0500

rcm (1.3.1) unstable; urgency=low

  * BUGFIX: Handle dotfile names with spaces in them (Eric Collins, Mike Burns).
  * BUGFIX: Relative exclude globs now work (Eric Collins, Mike Burns).
  * BUGFIX: Use $LOGNAME instead of $USER for compatibility (Mike Burns).
  * BUGFIX: rcdn(1) stops at DEST_DIR (Kyle Cook, Mike Burns).
  * BUGFIX: Symlink existing files, even when identical (Graham Bennett).
  * BUGFIX: Sort hooks by filename before execution instead of arbitrary order
    (David Alexander).
  * Documentation improvements (Nick Novitski, Ben Stephens, Casey Rodarmor).

 -- Mike Burns <mburns@thoughtbot.com>  Sat, 26 Dec 2016 17:00:00 -0500

rcm (1.3.0) unstable; urgency=low

  * BUGFIX: Control whether hooks should run in rcdn(1) with the -K and -k
    flags (Ben Turrubiates, Christopher Koch, Mike Burns, Mikkel Fahnøe
    Jørgensen).
  * Massive documentation fixes and updates (Christopher Koch, David Alexander,
    Jason Daniel Augustine Gilliland, Martin Frost, Melissa Xie, Mike Burns,
    Scott Stevenson, Jarkko Kniivilä, Blake Williams, Carl van Tonder, Teo
    Ljungberg, Zach Latta, Devraj Mehta, Vlad GURDIGA, Joe Ferris).
  * Host-specific files take priority, then tags, then default (Christian
    Höltje).
  * Run hooks in the directory in which they are located (Jarkko Kniivilä).
  * Generate a minimal standalone rcup(1) script with the -g flag (Mike Burns).
  * Support rc files without leading dots via the -U and -u flags in lsrc(1),
    rcup(1), and rcdn(1), and the UNDOTTED setting in rcrc(5) (Christopher
    Koch).
  * Improved Solaris support (Jarkko Kniivilä).
  * Override `SYMLINK_DIRS` or -S with -s (Mike Burns).
  * Show usage information when given bad arguments (Mike Burns).

 -- Mike Burns <mburns@thoughtbot.com>  Thu, 08 Jan 2015 14:50:00 +0200

rcm (1.2.3) unstable; urgency=low

  * BUGFIX: Allow files with the same prefix name in the same
    directory (Javier López).
  * BUGFIX: Pick up hooks that are executable by the user or by the
    group, instead of only files that are 777 (Christian Höltje).
  * Allow running mkrc on a relative file and preserve the
    path (Pablo Olmos de Aguilera Corradini).
  * A flag (-B), and a variable for rcrc(5) (HOSTNAME), for changing the
    hostname as rcm sees it. This is highly recommended under OS X (Mike
    Burns).
  * Transfer copyright to thoughtbot, under the same license (Mike Burns).

 -- Mike Burns <mburns@thoughtbot.com>  Fri, 09 May 2014 14:17:49 +0200

rcm (1.2.2) unstable; urgency=low

  * BUGFIX: Cygwin now executes hooks (Daniel Watson).
  * BUGFIX: Support -v option on OpenBSD (Javier López).
  * BUGFIX: Use a POSIX shell on Solaris (Mike Burns).
  * Documentation fixes (John Axel Eriksson, Mike Burns).
  * Packaging improvements (Mike Burns, Andrei Dziahel).

 -- Mike Burns <mburns@thoughtbot.com>  Mon, 03 Feb 2014 16:58:33 +0200

rcm (1.2.1) unstable; urgency=low

  * BUGFIX: Support multiple -d options when given relative paths (Mike
    Burns).
  * BUGFIX: Cygwin compatibility for hostname (Mike Burns).
  * Handle more files with spaces in their filename (Caleb Land, Pat
    Brisbin, Mike Burns).
  * Hooks in directories instead of just single executables (Pablo Olmos
    de Aguilera Corradini, Mike Burns, Pat Brisbin).
  * Option to force some directories to be symlinks, as documented under
    SYMLINK_DIRS in rcrc(5) and -S for lsrc(1) (Pablo Olmos de Aguilera
    Corradini).
  * Improved packaging process (Mike Burns).
  * Documentation fixes and updates (Jordan Eldredge, Anton Ilin, Mike
    Burns).

 -- Mike Burns <mburns@thoughtbot.com>  Mon, 03 Feb 2014 16:58:33 +0200

rcm (1.2.0) unstable; urgency=low

  * Transfer ownership to thoughtbot.
  * BUGFIX: Run hooks by default. Thanks to Patrick Brisbin.
  * BUGFIX: Unset CDPATH when starting. Thanks to Geoff Harcourt.
  * Override .rcrc location using RCRC environment variable. Thanks to
    Patrick Brisbin.
  * Upgrade to automake 1.14.
  * Improve mkrc verbose mode. Thanks to Pablo Olmos de Aguilera
    Corradini.
  * Use the thoughtbot/formulae Homebrew tap. Thanks to George
    Brocklehurst.
  * Manpage fixes thanks to Dan Croak and Roberto Pedroso.

 -- Mike Burns <mburns@thoughtbot.com>  Mon, 03 Feb 2014 16:58:33 +0200

rcm (1.1.0) unstable; urgency=low

  * BUGFIX: use a consistent method for computing hostname everywhere.
    Thanks to George Brocklehurst.
  * Exclusion and inclusion with -x and -I.
  * Copy instead of symlink with -C.
  * Always copy the files listed in COPY_ALWAYS.
  * Show whether the file is a copy or symlink using lsrc -F.
  * Add hooks for pre-up, post-up, pre-down, and post-down.
  * rcup -K and rcdn -K to ignore these hooks.

 -- Mike Burns <mburns@thoughtbot.com>  Mon, 05 Aug 2013 16:43:33 +0200

rcm (1.0.0) unstable; urgency=low

  * Improved Debian handling.
  * Introduce mkrc -o to install host-specific dotfiles.
  * Add rcdn(1) to remove rc files.
  * Add rcup -f and -i to force overwrites/prompt for overwrites.

 -- Mike Burns <mburns@thoughtbot.com>  Tue, 01 Aug 2013 16:43:33 +0200

rcm (0.0.2) unstable; urgency=low

  * Tutorial in rcm(7).
  * mkrc supports -d .
  * -d supports relative dotfile dirs.

 -- Mike Burns <mburns@thoughtbot.com>  Tue, 23 Jul 2013 16:43:33 +0200

==> rcm-1.3.6.tar.gz: rcm-1.3.6/NEWS.md <==
rcm (1.3.6) unstable; urgency=low

  * Feature: rcup/rcdn hooks can bail early (Patrick Brisbin)
  * Documentation improvement (Teo Ljungberg)
  
 -- Mike Burns <mburns@thoughtbot.com>  Fri, 30 Dec 2022 11:43:00 -0500

rcm (1.3.5) unstable; urgency=low

  * BUGFIX: *:*~ exclude paterns work again (Alexander Goldstein)
  * BUGFIX: messages for -C being a copy so can't update (Mat M).
  * BUGFIX: expect at least one existing dotfiles directory (Mat M).
  * BUGFIX: fix program name in rcdn -V (Ivan Tkachenko)
  * Feature: mkrc hooks via -k/-K (Patrick Brisbin)
  * Feature: All symlinks in input are rejected (Mat M).
  * Package and maintenance improvements (Alexander Goldstein, Eric Collins,
      Mat M, Darcy Parker).
  
 -- Mike Burns <mburns@thoughtbot.com>  Fri, 22 Apr 2022 15:59:43 -0400

rcm (1.3.4) unstable; urgency=low

  * BUGFIX: Globs no longer expand permanently (Edd Salkield).
  * BUGFIX: Show $ for symlinked dirs in `lsrc -F` (Mathias Michel).
  * BUGFIX: all symlinks in mkrc input are rejected (Mat M).
  * Packaging improvements (Stephen Groat, Martin Frost, Link Dupont)
  
 -- Mike Burns <mburns@thoughtbot.com>  Fri, 28 Aug 2022 16:38:25 -0400

rcm (1.3.3) unstable; urgency=low

  * Feature: Expand ~ in DOTFILES_DIR hooks (Eric Collins).

 -- Mike Burns <mburns@thoughtbot.com>  Fri, 13 Jul 2018 14:12:00 -0500

rcm (1.3.2) unstable; urgency=low

  * BUGFIX: Use =, not ==, in test(1) (Florian Tham).
  * BUGFIX: Directories with spaces in rcup(1) (Florian Tham).
  * BUGFIX: Fallback the LOGNAME from whoami (AJ Villalobos, Mike Burns).
  * BUGFIX: Fix cd for paths beginning with hyphen (-) (Christian Höltje).
  * Feature: Expand ~ in DOTFILES_DIR (Rebecca Meritz).
  * Documentation improvements (Alan Yee, Eric Collins, Florian Tham, kajisha,
	    Matthew Horan, maxice8, Mike Burns, Rebecca Meritz, Scott Stevenson,
	    Tyson Gach, Yota Toyama).

 -- Mike Burns <mburns@thoughtbot.com>  Fri, 06 Jul 2018 11:00:00 -0400

rcm (1.3.1) unstable; urgency=low

  * BUGFIX: Handle dotfile names with spaces in them (Eric Collins, Mike Burns).
  * BUGFIX: Relative exclude globs now work (Eric Collins, Mike Burns).
  * BUGFIX: Use $LOGNAME instead of $USER for compatibility (Mike Burns).
  * BUGFIX: rcdn(1) stops at DEST_DIR (Kyle Cook, Mike Burns).
  * BUGFIX: Symlink existing files, even when identical (Graham Bennett).
  * BUGFIX: Sort hooks by filename before execution instead of arbitrary order
    (David Alexander).
  * Documentation improvements (Nick Novitski, Ben Stephens, Casey Rodarmor).

 -- Mike Burns <mburns@thoughtbot.com>  Sat, 26 Dec 2016 17:00:00 -0500

rcm (1.3.0) unstable; urgency=low

  * BUGFIX: Control whether hooks should run in rcdn(1) with the -K and -k
    flags (Ben Turrubiates, Christopher Koch, Mike Burns, Mikkel Fahnøe
    Jørgensen).
  * Massive documentation fixes and updates (Christopher Koch, David Alexander,
    Jason Daniel Augustine Gilliland, Martin Frost, Melissa Xie, Mike Burns,
    Scott Stevenson, Jarkko Kniivilä, Blake Williams, Carl van Tonder, Teo
    Ljungberg, Zach Latta, Devraj Mehta, Vlad GURDIGA, Joe Ferris).
  * Host-specific files take priority, then tags, then default (Christian
    Höltje).
  * Run hooks in the directory in which they are located (Jarkko Kniivilä).
  * Generate a minimal standalone rcup(1) script with the -g flag (Mike Burns).
  * Support rc files without leading dots via the -U and -u flags in lsrc(1),
    rcup(1), and rcdn(1), and the UNDOTTED setting in rcrc(5) (Christopher
    Koch).
  * Improved Solaris support (Jarkko Kniivilä).
  * Override `SYMLINK_DIRS` or -S with -s (Mike Burns).
  * Show usage information when given bad arguments (Mike Burns).

 -- Mike Burns <mburns@thoughtbot.com>  Thu, 08 Jan 2015 14:50:00 +0200

rcm (1.2.3) unstable; urgency=low

  * BUGFIX: Allow files with the same prefix name in the same
    directory (Javier López).
  * BUGFIX: Pick up hooks that are executable by the user or by the
    group, instead of only files that are 777 (Christian Höltje).
  * Allow running mkrc on a relative file and preserve the
    path (Pablo Olmos de Aguilera Corradini).
  * A flag (-B), and a variable for rcrc(5) (HOSTNAME), for changing the
    hostname as rcm sees it. This is highly recommended under OS X (Mike
    Burns).
  * Transfer copyright to thoughtbot, under the same license (Mike Burns).

 -- Mike Burns <mburns@thoughtbot.com>  Fri, 09 May 2014 14:17:49 +0200

rcm (1.2.2) unstable; urgency=low

  * BUGFIX: Cygwin now executes hooks (Daniel Watson).
  * BUGFIX: Support -v option on OpenBSD (Javier López).
  * BUGFIX: Use a POSIX shell on Solaris (Mike Burns).
  * Documentation fixes (John Axel Eriksson, Mike Burns).
  * Packaging improvements (Mike Burns, Andrei Dziahel).

 -- Mike Burns <mburns@thoughtbot.com>  Mon, 03 Feb 2014 16:58:33 +0200

rcm (1.2.1) unstable; urgency=low

  * BUGFIX: Support multiple -d options when given relative paths (Mike
    Burns).
  * BUGFIX: Cygwin compatibility for hostname (Mike Burns).
  * Handle more files with spaces in their filename (Caleb Land, Pat
    Brisbin, Mike Burns).
  * Hooks in directories instead of just single executables (Pablo Olmos
    de Aguilera Corradini, Mike Burns, Pat Brisbin).
  * Option to force some directories to be symlinks, as documented under
    SYMLINK_DIRS in rcrc(5) and -S for lsrc(1) (Pablo Olmos de Aguilera
    Corradini).
  * Improved packaging process (Mike Burns).
  * Documentation fixes and updates (Jordan Eldredge, Anton Ilin, Mike
    Burns).

 -- Mike Burns <mburns@thoughtbot.com>  Mon, 03 Feb 2014 16:58:33 +0200

rcm (1.2.0) unstable; urgency=low

  * Transfer ownership to thoughtbot.
  * BUGFIX: Run hooks by default. Thanks to Patrick Brisbin.
  * BUGFIX: Unset CDPATH when starting. Thanks to Geoff Harcourt.
  * Override .rcrc location using RCRC environment variable. Thanks to
    Patrick Brisbin.
  * Upgrade to automake 1.14.
  * Improve mkrc verbose mode. Thanks to Pablo Olmos de Aguilera
    Corradini.
  * Use the thoughtbot/formulae Homebrew tap. Thanks to George
    Brocklehurst.
  * Manpage fixes thanks to Dan Croak and Roberto Pedroso.

 -- Mike Burns <mburns@thoughtbot.com>  Mon, 03 Feb 2014 16:58:33 +0200

rcm (1.1.0) unstable; urgency=low

  * BUGFIX: use a consistent method for computing hostname everywhere.
    Thanks to George Brocklehurst.
  * Exclusion and inclusion with -x and -I.
  * Copy instead of symlink with -C.
  * Always copy the files listed in COPY_ALWAYS.
  * Show whether the file is a copy or symlink using lsrc -F.
  * Add hooks for pre-up, post-up, pre-down, and post-down.
  * rcup -K and rcdn -K to ignore these hooks.

 -- Mike Burns <mburns@thoughtbot.com>  Mon, 05 Aug 2013 16:43:33 +0200

rcm (1.0.0) unstable; urgency=low

  * Improved Debian handling.
  * Introduce mkrc -o to install host-specific dotfiles.
  * Add rcdn(1) to remove rc files.
  * Add rcup -f and -i to force overwrites/prompt for overwrites.

 -- Mike Burns <mburns@thoughtbot.com>  Tue, 01 Aug 2013 16:43:33 +0200

rcm (0.0.2) unstable; urgency=low

  * Tutorial in rcm(7).
  * mkrc supports -d .
  * -d supports relative dotfile dirs.

 -- Mike Burns <mburns@thoughtbot.com>  Tue, 23 Jul 2013 16:43:33 +0200
